@@ -24,6 +24,7 @@
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
 #include <libgda/gda-field.h>
+#include <string.h>
 
 GType
 gda_field_attributes_get_type (void)
@@ -62,6 +63,7 @@ gda_field_attributes_new (void)
 	fa->auto_increment_start = 0;
 	fa->auto_increment_step = 0;
 	fa->position = -1;
+	fa->default_value = NULL;
 
 	return fa;
 }
@@ -96,6 +98,7 @@ gda_field_attributes_copy (GdaFieldAttributes *fa)
 	fa_copy->auto_increment_start = fa->auto_increment_start;
 	fa_copy->auto_increment_step = fa->auto_increment_step;
 	fa_copy->position = fa->position;
+	fa_copy->default_value = (fa_copy->default_value ? gda_value_copy (fa->default_value) : 0);
 
 	return fa_copy;
 }
@@ -115,9 +118,73 @@ gda_field_attributes_free (GdaFieldAttributes *fa)
 	g_free (fa->table);
 	g_free (fa->caption);
 	g_free (fa->references);
+	g_free (fa->default_value);
 	g_free (fa);
 }
 
+/**
+ * gda_field_attributes_equal:
+ * @lhs: a #GdaFieldAttributes
+ * @rhs: another #GdaFieldAttributes
+ *
+ * Tests whether two field attributes are equal.
+ *
+ * Return value: %TRUE if the field attributes contain the same information.
+ **/
+gboolean
+gda_field_attributes_equal (const GdaFieldAttributes *lhs,
+                            const GdaFieldAttributes *rhs)
+{
+  g_return_val_if_fail (lhs != NULL, FALSE);
+  g_return_val_if_fail (rhs != NULL, FALSE);
+
+  /* Compare every struct field: */
+  if ((lhs->defined_size != rhs->defined_size) ||
+          (lhs->scale != rhs->scale) ||
+          (lhs->gda_type != rhs->gda_type) ||
+          (lhs->allow_null != rhs->allow_null) ||
+          (lhs->primary_key != rhs->primary_key) ||
+          (lhs->unique_key != rhs->unique_key) ||
+          (lhs->auto_increment != rhs->auto_increment) ||
+          (lhs->auto_increment_step != rhs->auto_increment_step) ||
+          (lhs->position != rhs->position))  
+    return FALSE;
+
+  /* Check the strings if they have are not null.
+     Then check whether one is null while the other is not, because strcmp can not do that. */
+  if ((lhs->name && rhs->name) && (strcmp (lhs->name, rhs->name) != 0))
+    return FALSE;
+    
+  if ((lhs->name == 0) != (rhs->name == 0))
+    return FALSE;
+    
+  if ((lhs->table && rhs->table) && (strcmp (lhs->table, rhs->table) != 0))
+    return FALSE;
+
+  if ((lhs->table == 0) != (rhs->table == 0))
+    return FALSE;
+
+  if ((lhs->caption && rhs->caption) && (strcmp (lhs->caption, rhs->caption) != 0))
+    return FALSE;
+
+  if ((lhs->caption == 0) != (rhs->caption == 0))
+    return FALSE;
+    
+  if ((lhs->references && rhs->references) && (strcmp (lhs->references, rhs->references) != 0))
+    return FALSE;
+
+  if ((lhs->references == 0) != (rhs->references == 0))
+    return FALSE;
+    
+  if (lhs->default_value && rhs->default_value && gda_value_compare (lhs->default_value, rhs->default_value) != 0)
+    return FALSE;
+
+  if ((lhs->default_value == 0) != (rhs->default_value == 0))
+    return FALSE;
+    
+  return TRUE;
+}
+
 /**
  * gda_field_attributes_get_defined_size
  * @fa: a @GdaFieldAttributes.
@@ -462,3 +529,35 @@ gda_field_attributes_set_position (GdaFieldAttributes *fa, gint position)
 	fa->position = position;
 }
 
+
+/**
+ * gda_field_attributes_get_default_value
+ * @fa: a #GdaFieldAttributes.
+ *
+ * Returns: @fa's default value, as a #GdaValue object.
+ */
+const GdaValue *
+gda_field_attributes_get_default_value (GdaFieldAttributes *fa)
+{
+	g_return_val_if_fail (fa != NULL, NULL);
+	return (const GdaValue *) fa->default_value;
+}
+
+/**
+ * gda_field_attributes_set_default_value
+ * @fa: a #GdaFieldAttributes.
+ * @default_value: default #GdaValue for the field
+ *
+ * Sets @fa's default #GdaValue.
+ */
+void
+gda_field_attributes_set_default_value (GdaFieldAttributes *fa, const GdaValue *default_value)
+{
+	g_return_if_fail (fa != NULL);
+	g_return_if_fail (default_value != NULL);
+
+	if (fa->default_value)
+		g_free (fa->default_value);
+	fa->default_value = gda_value_copy ( (GdaValue*)default_value);
+}
+
