@@ -32,9 +32,20 @@ struct _GdaRow {
 	gint nfields;
 };
 
+GType gda_row_get_type (void)
+{
+	static GType our_type = 0;
+
+	if (our_type == 0)
+		our_type = g_boxed_type_register_static ("GdaRow",
+			(GBoxedCopyFunc) gda_row_copy,
+			(GBoxedFreeFunc) gda_row_free);
+	return our_type;
+}
+
 /**
  * gda_row_new
- * model: the #GdaDataModel this row belongs to.
+ * @model: the #GdaDataModel this row belongs to.
  * @count: number of #GdaValue in the new #GdaRow.
  *
  * Creates a #GdaRow which can hold @count #GdaValue.
@@ -60,9 +71,11 @@ gda_row_new (GdaDataModel *model, gint count)
 
 /**
  * gda_row_new_from_list
+ * @model: a #GdaDataModel.
  * @values: a list of #GdaValue's.
  *
- * Create a #GdaRow from a list of #GdaValue's.
+ * Creates a #GdaRow from a list of #GdaValue's.  These GdaValue's are
+ * value-copied and the user are still resposible for freeing them.
  *
  * Returns: the newly created row.
  */
@@ -106,11 +119,43 @@ gda_row_free (GdaRow *row)
 	g_free (row);
 }
 
+/**
+ * gda_row_copy
+ * @row: quark_list to get a copy from.
+ *
+ * Creates a new #GdaRow from an existing one.
+ * 
+ * Returns: a newly allocated #GdaRow with a copy of the data in @row.
+ */
+GdaRow *
+gda_row_copy (GdaRow *row)
+{
+	GdaRow *new_row;
+	gint i;
+
+	g_return_val_if_fail (row != NULL, NULL);
+
+	new_row = gda_row_new (row->model, row->nfields);
+	new_row->number = row->number;
+	new_row->id = g_strdup (row->id);
+
+	for (i = 0; i < row->nfields; i++) { 
+		GdaValue *value = &row->fields[i];
+		if (value)
+			gda_value_set_from_value (gda_row_get_value (new_row, i),
+						  gda_value_copy (value));
+		else
+			gda_value_set_null (gda_row_get_value (new_row, i));
+	}
+
+	return new_row;	
+}
+
 /**
  * gda_row_get_model
  * @row: a #GdaRow.
  *
- * Get the #GdaDataModel the given #GdaRow belongs to.
+ * Gets the #GdaDataModel the given #GdaRow belongs to.
  *
  * Returns: a #GdaDataModel.
  */
@@ -125,7 +170,7 @@ gda_row_get_model (GdaRow *row)
  * gda_row_get_number
  * @row: a #GdaRow.
  *
- * Get the number of the given row, that is, its position in its containing
+ * Gets the number of the given row, that is, its position in its containing
  * data model.
  *
  * Returns: the row number, or -1 if there was an error.
@@ -142,7 +187,7 @@ gda_row_get_number (GdaRow *row)
  * @row: a #GdaRow.
  * @number: the new row number.
  *
- * Set the row number for the given row.
+ * Sets the row number for the given row.
  */
 void
 gda_row_set_number (GdaRow *row, gint number)
@@ -155,7 +200,7 @@ gda_row_set_number (GdaRow *row, gint number)
  * gda_row_get_id
  * @row: a #GdaRow (which contains #GdaValue).
  *
- * Return the unique identifier for this row. This identifier is
+ * Returns the unique identifier for this row. This identifier is
  * assigned by the different providers, to uniquely identify
  * rows returned to clients. If there is no ID, this means that
  * the row has not been created by a provider, or that it the
@@ -173,10 +218,10 @@ gda_row_get_id (GdaRow *row)
 
 /**
  * gda_row_set_id
- * @row: A #GdaRow (which contains #GdaValue).
- * @id: New identifier for the row.
+ * @row: a #GdaRow (which contains #GdaValue).
+ * @id: new identifier for the row.
  *
- * Assign a new identifier to the given row. This function is
+ * Assigns a new identifier to the given row. This function is
  * usually called by providers.
  */
 void
@@ -212,9 +257,9 @@ gda_row_get_value (GdaRow *row, gint num)
 
 /**
  * gda_row_get_length
- * @row: a #GdaRow
+ * @row: a #GdaRow.
  *
- * Gets the number of columns that the row has.
+ * Returns: the number of columns that the @row has.
  */
 gint
 gda_row_get_length (GdaRow *row)
