@@ -75,11 +75,21 @@ struct _GdaServerProviderClass {
 	gboolean (* drop_database) (GdaServerProvider *provider,
 				    GdaConnection *cnc,
 				    const gchar *name);
+	gboolean (* create_table) (GdaServerProvider *provider,
+				   GdaConnection *cnc,
+				   const gchar *table_name,
+				   const GdaFieldAttributes *attributes[]);
+	gboolean (* drop_table) (GdaServerProvider *provider,
+				 GdaConnection *cnc,
+				 const gchar *table_name);
 
 	GList * (* execute_command) (GdaServerProvider *provider,
 				     GdaConnection *cnc,
 				     GdaCommand *cmd,
 				     GdaParameterList *params);
+	char * (* get_last_insert_id) (GdaServerProvider *provider,
+				       GdaConnection *cnc,
+				       GdaDataModel *recset);
 
 	gboolean (* begin_transaction) (GdaServerProvider *provider,
 					GdaConnection *cnc,
@@ -99,6 +109,10 @@ struct _GdaServerProviderClass {
 				       GdaConnection *cnc,
 				       GdaConnectionSchema schema,
 				       GdaParameterList *params);
+
+	gboolean (* create_blob) (GdaServerProvider *provider,
+				  GdaConnection *cnc,
+				  GdaBlob *blob);
 };
 
 GType    gda_server_provider_get_type (void);
@@ -124,11 +138,21 @@ gboolean gda_server_provider_create_database (GdaServerProvider *provider,
 gboolean gda_server_provider_drop_database (GdaServerProvider *provider,
 					    GdaConnection *cnc,
 					    const gchar *name);
+gboolean gda_server_provider_create_table (GdaServerProvider *provider,
+					   GdaConnection *cnc,
+					   const gchar *table_name,
+					   const GdaFieldAttributes *attributes[]);
+gboolean gda_server_provider_drop_table (GdaServerProvider *provider,
+					 GdaConnection *cnc,
+					 const gchar *table_name);
 
 GList   *gda_server_provider_execute_command (GdaServerProvider *provider,
 					      GdaConnection *cnc,
 					      GdaCommand *cmd,
 					      GdaParameterList *params);
+gchar   *gda_server_provider_get_last_insert_id (GdaServerProvider *provider,
+						 GdaConnection *cnc,
+						 GdaDataModel *recset);
 
 gboolean gda_server_provider_begin_transaction (GdaServerProvider *provider,
 						GdaConnection *cnc,
@@ -149,6 +173,10 @@ GdaDataModel *gda_server_provider_get_schema (GdaServerProvider *provider,
 					      GdaConnectionSchema schema,
 					      GdaParameterList *params);
 
+gboolean gda_server_provider_create_blob (GdaServerProvider *provider,
+					  GdaConnection *cnc,
+					  GdaBlob *blob);
+
 G_END_DECLS
 
 #endif
