@@ -20,12 +20,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <libgda/gda-intl.h>
 #include <libgda/gda-log.h>
 #include <libgda/gda-table.h>
 
-#define PARENT_TYPE GDA_TYPE_DATA_MODEL
+#define PARENT_TYPE GDA_TYPE_DATA_MODEL_ARRAY
 
 struct _GdaTablePrivate {
 	gchar *name;
@@ -42,10 +41,29 @@ static GObjectClass *parent_class = NULL;
  * GdaTable class implementation
  */
 
+typedef struct {
+	GdaTable *table;
+	gint col_to_search;
+	GdaFieldAttributes *fa;
+} DescColData;
+
+static void
+search_field_in_hash (gpointer key, gpointer value, gpointer user_data)
+{
+	DescColData *cb_data = user_data;
+	GdaFieldAttributes *fa = value;
+
+	if (cb_data->fa)
+		return;
+	if (gda_field_attributes_get_position (fa) == cb_data->col_to_search)
+		cb_data->fa = fa;
+}
+
 static GdaFieldAttributes *
 gda_table_describe_column (GdaDataModel *model, gint col)
 {
-	GdaFieldAttributes *fa = NULL, *new_fa;
+	DescColData cb_data;
+	GdaFieldAttributes *new_fa;
 	GdaTable *table = (GdaTable *) model;
 
 	g_return_val_if_fail (GDA_IS_TABLE (table), NULL);
@@ -53,14 +71,14 @@ gda_table_describe_column (GdaDataModel *model, gint col)
 	if (col >= g_hash_table_size (table->priv->fields))
 		return NULL;
 
-	/* FIXME: obtain 'fa' from hash table */
-	new_fa = gda_field_attributes_new ();
-	gda_field_attributes_set_defined_size (new_fa, fa->defined_size);
-	gda_field_attributes_set_name (new_fa, fa->name);
-	gda_field_attributes_set_scale (new_fa, fa->scale);
-	gda_field_attributes_set_gdatype (new_fa, fa->gda_type);
-	gda_field_attributes_set_allow_null (new_fa, fa->allow_null);
+	cb_data.table = table;
+	cb_data.col_to_search = col;
+	cb_data.fa = NULL;
+	g_hash_table_foreach (table->priv->fields, (GHFunc) search_field_in_hash, &cb_data);
+	if (!cb_data.fa)
+		return NULL;
 
+	new_fa = gda_field_attributes_copy (cb_data.fa);
 	return new_fa;
 }
 
@@ -143,9 +161,9 @@ gda_table_get_type (void)
 
 /**
  * gda_table_new
- * @name: Name for the new table.
+ * @name: name for the new table.
  *
- * Create a new #GdaTable object, which is an in-memory representation
+ * Creates a new #GdaTable object, which is an in-memory representation
  * of an entire table. It is mainly used by the #GdaXmlDatabase class,
  * but you can also use it in your applications for whatever you may need
  * it.
@@ -167,11 +185,11 @@ gda_table_new (const gchar *name)
 
 /**
  * gda_table_new_from_model
- * @name: Name for the new table.
- * @model: Model to create the table from.
- * @add_data: Whether to add model's data or not.
+ * @name: name for the new table.
+ * @model: model to create the table from.
+ * @add_data: whether to add model's data or not.
  *
- * Create a #GdaTable object from the given #GdaDataModel. This
+ * Creates a #GdaTable object from the given #GdaDataModel. This
  * is very useful to maintain an in-memory copy of a given
  * recordset obtained from a database. This is also used when
  * exporting data to a #GdaXmlDatabase object.
@@ -209,10 +227,42 @@ gda_table_new_from_model (const gchar *name, const GdaDataModel *model, gboolean
 	return table;
 }
 
+/**
+ * gda_table_get_name
+ * @table: a #GdaTable object.
+ *
+ * Returns: the name of the given #GdaTable.
+ */
+const gchar *
+gda_table_get_name (GdaTable *table)
+{
+	g_return_val_if_fail (GDA_IS_TABLE (table), NULL);
+	return (const gchar *) table->priv->name;
+}
+
+/**
+ * gda_table_set_name
+ * @table: a #GdaTable object.
+ * @name: new name for the table.
+ *
+ * Sets the name of the given #GdaTable.
+ */
+void
+gda_table_set_name (GdaTable *table, const gchar *name)
+{
+	g_return_if_fail (GDA_IS_TABLE (table));
+	g_return_if_fail (name != NULL);
+
+	if (table->priv->name)
+		g_free (table->priv->name);
+
+	table->priv->name = g_strdup (name);
+}
+
 /**
  * gda_table_add_field
- * @table: A #GdaTable object.
- * @fa: Attributes for the new field.
+ * @table: a #GdaTable object.
+ * @fa: attributes for the new field.
  *
  * Adds a field to the given #GdaTable.
  */
@@ -237,6 +287,8 @@ gda_table_add_field (GdaTable *table, const GdaFieldAttributes *fa)
 
 	/* add the new field to the table */
 	new_fa = gda_field_attributes_new ();
+	gda_field_attributes_set_table (new_fa, table->priv->name);
+	gda_field_attributes_set_position (new_fa, g_hash_table_size (table->priv->fields));
 	gda_field_attributes_set_defined_size (new_fa, gda_field_attributes_get_defined_size ((GdaFieldAttributes *) fa));
 	gda_field_attributes_set_name (new_fa, name);
 	gda_field_attributes_set_scale (new_fa, gda_field_attributes_get_scale ((GdaFieldAttributes *) fa));
@@ -250,10 +302,16 @@ gda_table_add_field (GdaTable *table, const GdaFieldAttributes *fa)
 
 /**
  * gda_table_add_data_from_model
+ * @table: a #GdaTable object.
+ * @model: a #GdaDataModel object.
+ *
+ * Adds data in the given @table from the given @model.
  */
 void
 gda_table_add_data_from_model (GdaTable *table, const GdaDataModel *model)
 {
 	g_return_if_fail (GDA_IS_TABLE (table));
 	g_return_if_fail (GDA_IS_DATA_MODEL (model));
+
+    /* FIXME: implement me */
 }
