@@ -244,7 +244,7 @@ gda_mdb_provider_close_connection (GdaServerProvider *provider, GdaConnection *c
 		mdb_cnc->server_version = NULL;
 	}
 
-	//mdb_free_handle (mdb_cnc->mdb);
+	/* mdb_free_handle (mdb_cnc->mdb); */
 
 	g_free (mdb_cnc);
 	g_object_set_data (G_OBJECT (cnc), OBJECT_DATA_MDB_HANDLE, NULL);
@@ -389,7 +389,7 @@ gda_mdb_provider_execute_command (GdaServerProvider *provider,
 			g_strfreev (arr);
 		}
 		break;
-	default :
+	default : ;
 	}
 
 	return reclist;
@@ -438,7 +438,7 @@ gda_mdb_provider_supports (GdaServerProvider *provider,
 	case GDA_CONNECTION_FEATURE_PROCEDURES :
 	case GDA_CONNECTION_FEATURE_SQL :
 		return TRUE;
-	default :
+	default : ;
 	}
 
 	return FALSE;
@@ -738,6 +738,12 @@ gda_mdb_provider_execute_sql (GdaMdbProvider *mdbprv, GdaConnection *cnc, const
 		mdb_sql_reset (mdb_SQL);
 		return NULL;
 	}
+	if (!mdb_SQL->cur_table) {
+		/* parsing went fine, but there is no result
+		   (e.g. because of an invalid column name) */
+		gda_connection_add_error_string (cnc, _("Got no result for '%s' command"), sql);
+		return NULL;
+	}
 
 	model = gda_table_new (sql);
 
