@@ -194,6 +194,16 @@ gda_odbc_provider_open_connection (GdaServerProvider *provider,
 		return FALSE;
 	}
 
+	/* set access mode */
+	if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+		rc = SQLSetConnectOption (priv_data->hdbc, SQL_ACCESS_MODE, SQL_MODE_READ_ONLY);
+
+		if (!SQL_SUCCEEDED (rc)) {
+			gda_odbc_emit_error (cnc, priv_data->henv,
+						priv_data->hdbc, SQL_NULL_HANDLE );
+		}
+	}
+
 	/* open the connection */
 	rc = SQLConnect (priv_data->hdbc,
 			 (SQLCHAR *) odbc_string, SQL_NTS,
@@ -222,7 +232,7 @@ gda_odbc_provider_open_connection (GdaServerProvider *provider,
 
 	/* get version info */
 
-	rc = SQLGetInfo ( priv_data->hdbc, SQL_DRIVER_VER,
+	rc = SQLGetInfo ( priv_data->hdbc, SQL_DBMS_VER,
 			priv_data->version, sizeof( priv_data->version ), NULL );
 
 	if ( !SQL_SUCCEEDED( rc )) {
@@ -261,27 +271,24 @@ gda_odbc_provider_close_connection (GdaServerProvider *provider,
 }
 
 static GList *
-process_sql_commands (GList *reclist, GdaConnection *cnc, GdaCommand *cmd)
+process_sql_commands (GList *reclist, GdaConnection *cnc, const gchar *sql, GdaCommandOptions opts)
 {
 	GdaOdbcConnectionData *priv_data;
 	GdaDataModelArray *recset;
-	GdaCommandOptions opts;
-	SQLCHAR *sql;
 	SQLSMALLINT ncols;
 	SQLRETURN rc;
+	SQLCHAR *sql_as_ansi;
 	int i;
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
-	g_return_val_if_fail (cmd != NULL, NULL);
 
 	priv_data = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_ODBC_HANDLE);
         if (!priv_data)
                 return NULL;
 
-	sql = (SQLCHAR*) gda_command_get_text ( cmd );
-	opts = gda_command_get_options ( cmd );
-
-	rc = SQLExecDirect ( priv_data->hstmt, sql, SQL_NTS );
+	sql_as_ansi = (SQLCHAR *) g_locale_from_utf8 (sql, -1, NULL, NULL, NULL);
+	rc = SQLExecDirect ( priv_data->hstmt, sql_as_ansi, SQL_NTS );
+	g_free (sql_as_ansi);
 	if ( SQL_SUCCEEDED( rc )) {
 		do
 		{
@@ -293,7 +300,7 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, GdaCommand *cmd)
 				for ( i = 1; i <= ncols; i ++ ) {
 					SQLCHAR name[ 256 ];
 					SQLSMALLINT nlen;
-					rc = SQLDescribeCol( priv_data->hstmt, 1,
+					rc = SQLDescribeCol( priv_data->hstmt, i,
 							name, sizeof( name ), &nlen, NULL, 
 							NULL, NULL, NULL );
 					if ( !SQL_SUCCEEDED( rc )) {
@@ -331,7 +338,9 @@ process_sql_commands (GList *reclist, GdaConnection *cnc, GdaCommand *cmd)
 								value, sizeof( value ), &ind );
 
 						if ( SQL_SUCCEEDED( rc ) && ind >= 0 ) {
-							value_list = g_list_append (value_list, gda_value_new_string ( value ));
+							gchar *value_as_utf = g_locale_to_utf8 (value, -1, NULL, NULL, NULL);
+							value_list = g_list_append (value_list, gda_value_new_string (value_as_utf));
+							g_free (value_as_utf);
 						}
 						else {
 							value_list = g_list_append (value_list, gda_value_new_string (""));
@@ -384,19 +393,28 @@ gda_odbc_provider_execute_command (GdaServerProvider *provider,
 				   GdaParameterList *params)
 {
 	GList *reclist = NULL;
+	gchar *str;
+	GdaCommandOptions options;
 
 	g_return_val_if_fail (GDA_IS_ODBC_PROVIDER (provider), NULL);
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 	g_return_val_if_fail (cmd != NULL, NULL);
 
 	/* execute command */
+	options = gda_command_get_options (cmd);
 	switch (gda_command_get_command_type (cmd)) {
 	case GDA_COMMAND_TYPE_SQL :
-		reclist = process_sql_commands (reclist, cnc, cmd);
+		reclist = process_sql_commands (reclist, cnc, gda_command_get_text (cmd),
+						options);
+		break;
+
+	case GDA_COMMAND_TYPE_TABLE :
+		str = g_strdup_printf ("SELECT * FROM %s", gda_command_get_text (cmd));
+		reclist = process_sql_commands (reclist, cnc, str, options);
+		g_free (str);
 		break;
 
 	/* FIXME: do these types */
-	case GDA_COMMAND_TYPE_TABLE :
 	case GDA_COMMAND_TYPE_PROCEDURE:
 	case GDA_COMMAND_TYPE_SCHEMA:
 		break;
@@ -623,6 +641,23 @@ gda_odbc_provider_supports (GdaServerProvider *provider,
 		}
 		break;
 
+	case GDA_CONNECTION_FEATURE_NAMESPACES :
+		rc = SQLGetInfo( priv_data -> hdbc, SQL_OWNER_USAGE, 
+				&ival, sizeof( ival ), NULL );
+
+		if ( SQL_SUCCEEDED( rc )) {
+			if ( ival ) {
+				return TRUE;
+			}
+			else {
+				return FALSE;
+			}
+		}
+		else {
+			return FALSE;
+		}
+		break;
+
 	case GDA_CONNECTION_FEATURE_PROCEDURES :
 		rc = SQLGetInfo( priv_data -> hdbc, SQL_PROCEDURES, 
 				yn, sizeof( yn ), NULL );
@@ -945,6 +980,77 @@ get_odbc_fields_metadata (GdaConnection *cnc, GdaParameterList *params)
 	return GDA_DATA_MODEL (recset);
 }
 
+static SQLRETURN 
+get_namespaces_rs( GdaOdbcConnectionData *priv_data, GdaDataModelArray *recset )
+{
+	SQLRETURN rc;
+
+	while( SQL_SUCCEEDED(( rc = SQLFetch ( priv_data->hstmt)))) {
+		GList *value_list = NULL;
+		SQLCHAR value[ 256 ];
+		SQLINTEGER ind;
+
+		/* owner */
+		rc = SQLGetData ( priv_data->hstmt, 2, SQL_C_CHAR,
+					value, sizeof( value ), &ind );
+
+		if ( SQL_SUCCEEDED( rc ) && ind >= 0 ) {
+			value_list = g_list_append (value_list, gda_value_new_string ( value ));
+		}
+		else {
+			value_list = g_list_append (value_list, gda_value_new_string (""));
+		}
+
+
+		gda_data_model_append_row (GDA_DATA_MODEL (recset), value_list);
+
+		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
+		g_list_free (value_list);
+	}
+
+	return rc;
+}
+
+static GdaDataModel *
+get_odbc_namespaces (GdaConnection *cnc, GdaParameterList *params)
+{
+	GdaDataModelArray *recset;
+	GdaOdbcConnectionData *priv_data;
+	SQLRETURN rc;
+
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+
+	/* create the recordset */
+	recset = GDA_DATA_MODEL_ARRAY (gda_data_model_array_new (1));
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 0, _("Owner"));
+
+	/* fill the recordset */
+	priv_data = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_ODBC_HANDLE);
+
+	/* generate the results */
+	rc = SQLTables ( priv_data->hstmt, NULL, 0,
+						(SQLCHAR*) "%", SQL_NTS,
+						NULL, 0,
+						NULL, 0 );
+
+	if ( SQL_SUCCEEDED( rc ))
+	{
+		rc = get_namespaces_rs( priv_data, recset );
+
+		if ( rc != SQL_NO_DATA )
+		{
+			gda_odbc_emit_error ( cnc, priv_data->henv,
+						priv_data->hdbc, priv_data->hstmt );
+			SQLFreeStmt( priv_data->hstmt, SQL_CLOSE );
+			return NULL;
+		}
+	}
+
+	SQLFreeStmt( priv_data->hstmt, SQL_CLOSE );
+
+	return GDA_DATA_MODEL (recset);
+}
+
 static SQLRETURN 
 get_procedure_rs( GdaOdbcConnectionData *priv_data, GdaDataModelArray *recset )
 {
@@ -1372,6 +1478,10 @@ gda_odbc_provider_get_schema (GdaServerProvider *provider,
 		return get_odbc_indexes (cnc, params);
 	case GDA_CONNECTION_SCHEMA_FIELDS:
 		return get_odbc_fields_metadata (cnc, params);
+	case GDA_CONNECTION_SCHEMA_NAMESPACES:
+		if ( !gda_odbc_provider_supports (provider, cnc, GDA_CONNECTION_FEATURE_NAMESPACES) )
+			return NULL;
+		return get_odbc_namespaces (cnc, params);
 	case GDA_CONNECTION_SCHEMA_PROCEDURES:
 		return get_odbc_procedures (cnc, params);
 	case GDA_CONNECTION_SCHEMA_TABLES:
